| Copyright | (c) 2025 |
|---|---|
| License | MIT |
| Maintainer | mschavinda@gmail.com |
| Safe Haskell | None |
| Language | GHC2021 |
Granite.Chart
Description
Convenience builders that construct a Chart from the same kinds of
arguments accepted by the legacy chart functions in Granite. Use
these when you want the declarative IR while still keeping ergonomic
construction:
import Granite.Chart
import qualified Data.Text.IO as T
import Granite.Render.Pipeline
main = do
let ch = scatterChart
[(A, [(0,0),(1,1),(2,4)])
,(B, [(0,1),(1,3),(2,6)])
] (Just "Random points")
T.putStrLn (renderChartTerminal ch)